@@ -141,7 +141,7 @@ test_bed <- function() {
   test <- import(test_bed_out)
   checkIdentical(correct_ucsc2, test)
 
-  test_bed_url <- paste("file:///", test_bed_out, sep = "")
+  test_bed_url <- paste("file://", test_bed_out, sep = "")
   export(correct_ucsc, test_bed_url)
   test <- import(test_bed_url)
   checkIdentical(correct_ucsc, test)
@@ -174,7 +174,7 @@ if (FALSE) { # enable to test an HTTP URL using the R help server
   test <- import(test_bed_gz)
   checkIdentical(correct_list, test)
   
-  test_bed_gz_url <- paste("file:///", test_bed_gz, sep = "")
+  test_bed_gz_url <- paste("file://", test_bed_gz, sep = "")
   export(correct_ucsc, test_bed_gz_url)
   test <- import(test_bed_gz_url)
   checkIdentical(correct_ucsc, test)
